@@ -6,6 +6,7 @@ import enum
 import requests
 from requests import Response
 
+from knowledge.services import USER_AGENT_STR
 from knowledge.services.base import WacomServiceAPIClient, WacomServiceException
 
 
@@ -20,6 +21,7 @@ INTERNAL_USER_ID_TAG: str = 'internalUserId'
 EXTERNAL_USER_ID_TAG: str = 'externalUserId'
 CONTENT_TYPE_FLAG: str = 'Content-Type'
 TENANT_API_KEY_FLAG: str = 'x-tenant-api-key'
+USER_AGENT_TAG: str = "User-Agent"
 
 
 class UserRole(enum.Enum):
@@ -126,9 +128,9 @@ class UserManagementServiceAPI(WacomServiceAPIClient):
     """
 
     USER_DETAILS_ENDPOINT: str = f'{WacomServiceAPIClient.USER_ENDPOINT}/internal-id'
-    SERVICE_URL: str = 'https://semantic-ink-private.wacom.com'
+    SERVICE_URL: str = 'https://stage-private-knowledge.wacom.com'
 
-    def __init__(self, service_url: str = SERVICE_URL, service_endpoint: str = 'graphdata'):
+    def __init__(self, service_url: str = SERVICE_URL, service_endpoint: str = 'graph'):
         super().__init__("GroupManagementServiceAPI", service_url=service_url, service_endpoint=service_endpoint)
 
     # ------------------------------------------ Users handling --------------------------------------------------------
@@ -163,6 +165,7 @@ class UserManagementServiceAPI(WacomServiceAPIClient):
         """
         url: str = f'{self.service_base_url}{UserManagementServiceAPI.USER_ENDPOINT}'
         headers: dict = {
+            USER_AGENT_TAG: USER_AGENT_STR,
             TENANT_API_KEY_FLAG: tenant_key,
             CONTENT_TYPE_FLAG: 'application/json'
         }
@@ -202,6 +205,7 @@ class UserManagementServiceAPI(WacomServiceAPIClient):
         """
         url: str = f'{self.service_base_url}{UserManagementServiceAPI.USER_ENDPOINT}'
         headers: Dict[str, str] = {
+            USER_AGENT_TAG: USER_AGENT_STR,
             TENANT_API_KEY_FLAG: tenant_key,
             CONTENT_TYPE_FLAG: 'application/json'
         }
@@ -237,6 +241,7 @@ class UserManagementServiceAPI(WacomServiceAPIClient):
         """
         url: str = f'{self.service_base_url}{UserManagementServiceAPI.USER_ENDPOINT}'
         headers: Dict[str, str] = {
+            USER_AGENT_TAG: USER_AGENT_STR,
             TENANT_API_KEY_FLAG: tenant_key
         }
         params: Dict[str, str] = {
@@ -269,6 +274,7 @@ class UserManagementServiceAPI(WacomServiceAPIClient):
         """
         url: str = f'{self.service_base_url}{UserManagementServiceAPI.USER_DETAILS_ENDPOINT}'
         headers: dict = {
+            USER_AGENT_TAG: USER_AGENT_STR,
             TENANT_API_KEY_FLAG: tenant_key
         }
         parameters: Dict[str, str] = {
@@ -300,6 +306,7 @@ class UserManagementServiceAPI(WacomServiceAPIClient):
         """
         url: str = f'{self.service_url}/{self.service_endpoint}{UserManagementServiceAPI.USER_ENDPOINT}'
         headers: Dict[str, str] = {
+            USER_AGENT_TAG: USER_AGENT_STR,
             TENANT_API_KEY_FLAG: tenant_key
         }
         params: Dict[str, str] = {
